@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0002'; #VERSION
+our $VERSION = '0.001'; #VERSION
 
 use Sort::Versions;
 
@@ -244,7 +244,7 @@ Python::Version - Python PEP440 compatible version string parser in Perl
 
 =head1 VERSION
 
-version 0.0002
+version 0.001
 
 =head1 SYNOPSIS
 
@@ -319,15 +319,25 @@ PEP 440 L<https://www.python.org/dev/peps/pep-0440/>
 
 Stephan Loyd <sloyd@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords perlancar
+=for stopwords perlancar Mohammad S Anwar
+
+=over 4
+
+=item *
 
 perlancar <perlancar@cpan.org>
 
+=item *
+
+Mohammad S Anwar <manwar@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Stephan Loyd.
+This software is copyright (c) 2018-2023 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
